/*
 *   Copyright (C) 1984-1991 The Santa Cruz Operation, Inc.
*            All Rights Reserved.
 *     The information in this file is provided for the exclusive use of
 *      the licensees of The Santa Cruz Operation, Inc.  Such users have the
 *      right to use, modify, and incorporate this code into other products
 *      for purposes authorized by the license agreement provided they include
 *      this notice and the associated copyright notice with any such product.
 *     The information in this file is provided "AS IS" without warranty.
 *   This Module contains Proprietary Information of
 *  The Santa Cruz Operation, and should be treated as Confidential.
 */

#ifndef _STDLIB_H
#define _STDLIB_H

#ifdef __STDC__
#pragma comment(exestr, "@(#) stdlib.h 10.6 92/05/29 ")
#else
#ident "@(#) stdlib.h 10.6 92/05/29 "
#endif

#if  !_STRICT_NAMES && !defined(_STRICTNAME_H)
#include  <strictname.h>
#endif

#if	defined(_XOPEN_SOURCE) && defined(_XOPEN_XPG4)
#ifndef	_STDDEF_H
#include	<stddef.h>
#endif
#ifndef	_LIMITS_H
#include	<limits.h>
#endif
#ifndef	_MATH_H
#include	<math.h>
#endif
#ifndef	_WCHAR_H
#include	<wchar.h>
#endif
#endif

#ifdef    _M_I386
#pragma   pack(4)
#else
#pragma   pack(2)
#endif

#define EXIT_FAILURE   1
#define EXIT_SUCCESS   0

#define MB_CUR_MAX     1

#ifndef NULL
#if defined(_KR) || defined(__cplusplus)
#define NULL 0
#else
#define NULL ((void *)0)
#endif
#endif

#define RAND_MAX       077777

#ifndef _DIV_T
#define _DIV_T
typedef struct { int quot; int rem; } div_t;
#endif

#ifndef _LDIV_T
#define _LDIV_T
typedef struct { long   quot; long   rem; } ldiv_t;
#endif

#ifndef _SIZE_T
#define _SIZE_T
typedef unsigned int size_t;
#endif

#ifndef _WCHAR_T
#define _WCHAR_T
typedef int wchar_t;   
#endif

#if defined(_NO_PROTOTYPE)
#if defined(_SVID) || defined(_KR)
extern char     *calloc();
extern char     *malloc();
extern char     *realloc();
extern char     *bsearch();
#else
extern void     *calloc();
extern void     *malloc();
extern void     *realloc();
extern void     *bsearch();
#endif /* _SVID || _KR */
extern double        atof();
extern int           atoi();
extern long          atol();
#if  !defined(_POSIX_SOURCE) && !defined (__STRICT_ANSI__)
extern double        drand48();
extern double        erand48();
extern long int      jrand48();
extern void          lcong48();
extern long int      lrand48();
extern long int      mrand48();
extern long int      nrand48();
extern int           putenv();
extern unsigned short int *   seed48();
extern void          setkey();
extern void          srand48();
#endif

extern double        strtod(); 
extern long          strtol();
extern unsigned long strtoul();
extern int           rand();
extern void          srand();
extern void          free();
extern void          abort();
extern int           atexit();
extern void          exit();
extern char          *getenv();
extern int           system();
extern void          qsort();
extern int           abs();
extern div_t         div();
extern long          labs();
extern ldiv_t        ldiv();
extern int           mblen();
extern int           mbtowc(); 
extern int           wctomb();
extern size_t        mbstowcs(); 
extern size_t        wcstombs(); 
#else /* !_NO_PROTOTYPE */

#if __cplusplus
#ifdef _COMPAT322
/*
 * There is no good reason to include these automagically except for
 * compatibility
 */
#ifndef	_STDDEF_H
#include <stddef.h>
#endif
#ifndef	_PWD_H
#include <pwd.h>
#endif
#ifndef	_RAND48_H
#include <rand48.h>
#endif
#ifndef	_REGCMP_H
#include <regcmp.h>
#endif
#ifndef	_ERRNO_H
#include <errno.h>
#endif
#ifndef	_MALLOC_H
#include <malloc.h>
#endif
#endif /* _COMPAT322 */
extern "C" {
#ifdef _COMPAT322
/*
 * The following are correctly declared in other header files and are
 * also declared here only for compatibility reasons
 */
 
extern char *ecvt(double, int, int*, int*);
extern double fabs(double);
extern char* fcvt(double, int, int*, int*);
extern double frexp(double, int*);
extern char *gcvt(double, int, char*);
extern char *getlogin();
extern char *getpass(const char*);
extern int getpw(int, char*);
extern int isatty(int);
extern double ldexp(double, int);
extern double modf(double, double*);
extern void perror(const char*);
extern void swab(const char*, char*, int);
extern long time(long*);
extern char *tmpnam(char*);
extern char *ttyname(int);
extern char *ctermid(char*);
extern char *cuserid(char*);
extern char *tempnam(const char*, const char*);
extern int getopt(int, const char* const*, const char*);
extern char *getcwd(char *, size_t);
extern void l3tol(long*, const char*, int);
extern char *l64a(long);
extern long a64l(const char*);
extern void ltol3(char*, const long*, int);
extern int putenv(const char*);
extern unsigned sleep(unsigned);
extern long sgetl(const char*);
extern void sputl(long, char*);

/*
 * And these are, presently, declared ONLY for C++
 */
 
extern char *mktemp(char*);
extern int ttyslot(void);
extern int getmsg(int, struct strbuf *, struct strbuf *, int *);

extern int optind, opterr;
extern char *optarg;
#endif /* _COMPAT322 */
#endif /* __cplusplus */

#if defined(_SVID) || defined(_KR)
extern char          *calloc(size_t, size_t);
extern char          *malloc(size_t);
extern char          *realloc(void *, size_t);
extern char          *bsearch(const void *, const void *, size_t, size_t, 
                                int (*)(const void *, const void *));
#else
extern void          *calloc(size_t, size_t);
extern void          *malloc(size_t);
extern void          *realloc(void *, size_t);
extern void          *bsearch(const void *, const void *, size_t, size_t, 
                                int (*)(const void *, const void *));
#endif /* _SVID || _KR */
extern void          qsort(void *, size_t, size_t, 
                             int(*)(const void *, const void *));
extern double        atof(const char *);
extern int           atoi(const char *);
extern long          atol(const char *);
#if	!defined(_POSIX_SOURCE) && !defined (__STRICT_ANSI__)
extern double        drand48( void );		
extern double        erand48( unsigned short int [3] );		
extern long int      jrand48( unsigned short int [3] );		
extern void          lcong48( unsigned short int [3] );		
extern long int      lrand48( void );
extern long int      mrand48( void );
extern long int      nrand48( unsigned short int [3] );
extern int           putenv( const char * );
extern unsigned short int *	seed48( unsigned short int [3] );
extern void          setkey( const char * );
extern void          srand48( long int );
#endif
extern double        strtod(const char *, char **); 
extern long          strtol(const char *, char **, int);
extern unsigned long strtoul(const char *, char **, int);
extern int           rand(void);
extern void          srand(unsigned int);
extern void          free(void *);
extern void          abort(void);
extern int           atexit(void (*)(void));
extern void          exit(int);
extern char          *getenv(const char *);
extern int           system(const char *);
#ifdef __cplusplus
#ifndef _ABS_INL
#define _ABS_INL
inline int abs(int i) {return (i > 0) ? i : -i;}
#endif
#else
extern int           abs(int);
#endif /* __cplusplus */
extern div_t         div(int, int);
extern long          labs(long int);
extern ldiv_t        ldiv(long int, long int);
extern int           mblen(const char *, size_t);
extern int           mbtowc(wchar_t *, const char *, size_t); 
extern int           wctomb(char *, wchar_t);
extern size_t        mbstowcs(wchar_t *, const char *, size_t); 
extern size_t        wcstombs(char *, const wchar_t *, size_t); 

#if __cplusplus
};
#endif /* __cplusplus */

#endif /* !_NO_PROTOTYPE */

#pragma	pack()

#endif   /* _STDLIB_H */
